summaryrefslogtreecommitdiff
path: root/include/cppuhelper/implbase13.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-10-20 11:02:14 +0200
committerNoel Grandin <noelgrandin@gmail.com>2015-10-21 06:36:39 +0000
commit08233bd25849cc7d5d092aa073362c7766cbcc19 (patch)
treeef27b8d8b00e531e31eea084f7cce81b6cb0bcb2 /include/cppuhelper/implbase13.hxx
parentd4d18b8613ab3ae38fe1ce1e3300e23ee6d42d44 (diff)
com::sun::star->css in include/cppuhelper
Change-Id: I3d9dcd4cd756a3f0d9cedd894377a117c9dbeecc Reviewed-on: https://gerrit.libreoffice.org/19486 Reviewed-by: Noel Grandin <noelgrandin@gmail.com> Tested-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'include/cppuhelper/implbase13.hxx')
-rw-r--r--include/cppuhelper/implbase13.hxx78
1 files changed, 39 insertions, 39 deletions
diff --git a/include/cppuhelper/implbase13.hxx b/include/cppuhelper/implbase13.hxx
index b99d62cfb5cc..da99200746f9 100644
--- a/include/cppuhelper/implbase13.hxx
+++ b/include/cppuhelper/implbase13.hxx
@@ -58,7 +58,7 @@ namespace cppu
CPPUHELPER_DETAIL_TYPEENTRY(Ifc11),
CPPUHELPER_DETAIL_TYPEENTRY(Ifc12),
CPPUHELPER_DETAIL_TYPEENTRY(Ifc13),
- CPPUHELPER_DETAIL_TYPEENTRY(com::sun::star::lang::XTypeProvider)
+ CPPUHELPER_DETAIL_TYPEENTRY(css::lang::XTypeProvider)
}
};
return reinterpret_cast< class_data * >(&s_cd);
@@ -67,7 +67,7 @@ namespace cppu
/// @endcond
/** Implementation helper implementing interface com::sun::star::lang::XTypeProvider
and method XInterface::queryInterface(), but no reference counting.
@derive
@@ -77,16 +77,16 @@ namespace cppu
*/
template< class Ifc1, class Ifc2, class Ifc3, class Ifc4, class Ifc5, class Ifc6, class Ifc7, class Ifc8, class Ifc9, class Ifc10, class Ifc11, class Ifc12, class Ifc13 >
class SAL_NO_VTABLE SAL_DLLPUBLIC_TEMPLATE ImplHelper13
- : public com::sun::star::lang::XTypeProvider
+ : public css::lang::XTypeProvider
, public Ifc1, public Ifc2, public Ifc3, public Ifc4, public Ifc5, public Ifc6, public Ifc7, public Ifc8, public Ifc9, public Ifc10, public Ifc11, public Ifc12, public Ifc13
{
struct cd : public rtl::StaticAggregate< class_data, ImplClassData13< Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10, Ifc11, Ifc12, Ifc13, ImplHelper13<Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10, Ifc11, Ifc12, Ifc13> > > {};
public:
- virtual com::sun::star::uno::Any SAL_CALL queryInterface( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_query( rType, cd::get(), this ); }
- virtual com::sun::star::uno::Sequence< com::sun::star::uno::Type > SAL_CALL getTypes() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getTypes( cd::get() ); }
- virtual com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
#if !defined _MSC_VER // public -> protected changes mangled names there
@@ -94,9 +94,9 @@ namespace cppu
#endif
~ImplHelper13() throw () {}
};
- /** Implementation helper implementing interfaces com::sun::star::lang::XTypeProvider and
- com::sun::star::uno::XInterface which supports weak mechanism to be held weakly
- (supporting com::sun::star::uno::XWeak through ::cppu::OWeakObject).
+ /** Implementation helper implementing interfaces css::lang::XTypeProvider and
+ css::uno::XInterface which supports weak mechanism to be held weakly
+ (supporting css::uno::XWeak through ::cppu::OWeakObject).
@derive
Inherit from this class giving your interface(s) to be implemented as template argument(s).
@@ -105,27 +105,27 @@ namespace cppu
template< class Ifc1, class Ifc2, class Ifc3, class Ifc4, class Ifc5, class Ifc6, class Ifc7, class Ifc8, class Ifc9, class Ifc10, class Ifc11, class Ifc12, class Ifc13 >
class SAL_NO_VTABLE SAL_DLLPUBLIC_TEMPLATE WeakImplHelper13
: public OWeakObject
- , public com::sun::star::lang::XTypeProvider
+ , public css::lang::XTypeProvider
, public Ifc1, public Ifc2, public Ifc3, public Ifc4, public Ifc5, public Ifc6, public Ifc7, public Ifc8, public Ifc9, public Ifc10, public Ifc11, public Ifc12, public Ifc13
{
struct cd : public rtl::StaticAggregate< class_data, ImplClassData13< Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10, Ifc11, Ifc12, Ifc13, WeakImplHelper13<Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10, Ifc11, Ifc12, Ifc13> > > {};
public:
- virtual com::sun::star::uno::Any SAL_CALL queryInterface( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakImplHelper_query( rType, cd::get(), this, static_cast<OWeakObject *>(this) ); }
virtual void SAL_CALL acquire() throw () SAL_OVERRIDE
{ OWeakObject::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ OWeakObject::release(); }
- virtual com::sun::star::uno::Sequence< com::sun::star::uno::Type > SAL_CALL getTypes() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakImplHelper_getTypes( cd::get() ); }
- virtual com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
- /** Implementation helper implementing interfaces com::sun::star::lang::XTypeProvider and
- com::sun::star::uno::XInterface which supports weak mechanism to be held weakly
- (supporting com::sun::star::uno::XWeak through ::cppu::OWeakAggObject).
+ /** Implementation helper implementing interfaces css::lang::XTypeProvider and
+ css::uno::XInterface which supports weak mechanism to be held weakly
+ (supporting css::uno::XWeak through ::cppu::OWeakAggObject).
In addition, it supports also aggregation meaning object of this class can be aggregated
- (com::sun::star::uno::XAggregation through ::cppu::OWeakAggObject).
+ (css::uno::XAggregation through ::cppu::OWeakAggObject).
If a delegator is set (this object is aggregated), then incoming queryInterface()
calls are delegated to the delegator object. If the delegator does not support the
demanded interface, it calls queryAggregation() on its aggregated objects.
@@ -137,33 +137,33 @@ namespace cppu
template< class Ifc1, class Ifc2, class Ifc3, class Ifc4, class Ifc5, class Ifc6, class Ifc7, class Ifc8, class Ifc9, class Ifc10, class Ifc11, class Ifc12, class Ifc13 >
class SAL_NO_VTABLE SAL_DLLPUBLIC_TEMPLATE WeakAggImplHelper13
: public OWeakAggObject
- , public com::sun::star::lang::XTypeProvider
+ , public css::lang::XTypeProvider
, public Ifc1, public Ifc2, public Ifc3, public Ifc4, public Ifc5, public Ifc6, public Ifc7, public Ifc8, public Ifc9, public Ifc10, public Ifc11, public Ifc12, public Ifc13
{
struct cd : public rtl::StaticAggregate< class_data, ImplClassData13< Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10, Ifc11, Ifc12, Ifc13, WeakAggImplHelper13<Ifc1, Ifc2, Ifc3, Ifc4, Ifc5, Ifc6, Ifc7, Ifc8, Ifc9, Ifc10, Ifc11, Ifc12, Ifc13> > > {};
public:
- virtual com::sun::star::uno::Any SAL_CALL queryInterface( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return OWeakAggObject::queryInterface( rType ); }
- virtual com::sun::star::uno::Any SAL_CALL queryAggregation( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryAggregation( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakAggImplHelper_queryAgg( rType, cd::get(), this, static_cast<OWeakAggObject *>(this) ); }
virtual void SAL_CALL acquire() throw () SAL_OVERRIDE
{ OWeakAggObject::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ OWeakAggObject::release(); }
- virtual com::sun::star::uno::Sequence< com::sun::star::uno::Type > SAL_CALL getTypes() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakAggImplHelper_getTypes( cd::get() ); }
- virtual com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
- /** Implementation helper implementing interfaces com::sun::star::lang::XTypeProvider and
- com::sun::star::uno::XInterface inherting from a BaseClass.
+ /** Implementation helper implementing interfaces css::lang::XTypeProvider and
+ css::uno::XInterface inherting from a BaseClass.
All acquire() and release() calls are delegated to the BaseClass. Upon queryInterface(),
if a demanded interface is not supported by this class directly, the request is
delegated to the BaseClass.
@attention
- The BaseClass has to be complete in a sense, that com::sun::star::uno::XInterface
- and com::sun::star::lang::XTypeProvider are implemented properly. The
+ The BaseClass has to be complete in a sense, that css::uno::XInterface
+ and css::lang::XTypeProvider are implemented properly. The
BaseClass must have at least one ctor that can be called with six or
fewer arguments, of which none is of non-const reference type.
@@ -206,9 +206,9 @@ namespace cppu
BaseClass(arg1, arg2, arg3, arg4, arg5, arg6) {}
public:
ImplInheritanceHelper13() {}
- virtual com::sun::star::uno::Any SAL_CALL queryInterface( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
- com::sun::star::uno::Any aRet( ImplHelper_queryNoXInterface( rType, cd::get(), this ) );
+ css::uno::Any aRet( ImplHelper_queryNoXInterface( rType, cd::get(), this ) );
if (aRet.hasValue())
return aRet;
return BaseClass::queryInterface( rType );
@@ -217,20 +217,20 @@ namespace cppu
{ BaseClass::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ BaseClass::release(); }
- virtual com::sun::star::uno::Sequence< com::sun::star::uno::Type > SAL_CALL getTypes() throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException) SAL_OVERRIDE
{ return ImplInhHelper_getTypes( cd::get(), BaseClass::getTypes() ); }
- virtual com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
- /** Implementation helper implementing interfaces com::sun::star::lang::XTypeProvider and
- com::sun::star::uno::XInterface inherting from a BaseClass.
+ /** Implementation helper implementing interfaces css::lang::XTypeProvider and
+ css::uno::XInterface inherting from a BaseClass.
All acquire(), release() and queryInterface() calls are delegated to the BaseClass.
Upon queryAggregation(), if a demanded interface is not supported by this class directly,
the request is delegated to the BaseClass.
@attention
- The BaseClass has to be complete in a sense, that com::sun::star::uno::XInterface,
- com::sun::star::uno::XAggregation and com::sun::star::lang::XTypeProvider
+ The BaseClass has to be complete in a sense, that css::uno::XInterface,
+ css::uno::XAggregation and css::lang::XTypeProvider
are implemented properly. The BaseClass must have at least one ctor
that can be called with six or fewer arguments, of which none is of
non-const reference type.
@@ -274,11 +274,11 @@ namespace cppu
BaseClass(arg1, arg2, arg3, arg4, arg5, arg6) {}
public:
AggImplInheritanceHelper13() {}
- virtual com::sun::star::uno::Any SAL_CALL queryInterface( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{ return BaseClass::queryInterface( rType ); }
- virtual com::sun::star::uno::Any SAL_CALL queryAggregation( com::sun::star::uno::Type const & rType ) throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryAggregation( css::uno::Type const & rType ) throw (css::uno::RuntimeException) SAL_OVERRIDE
{
- com::sun::star::uno::Any aRet( ImplHelper_queryNoXInterface( rType, cd::get(), this ) );
+ css::uno::Any aRet( ImplHelper_queryNoXInterface( rType, cd::get(), this ) );
if (aRet.hasValue())
return aRet;
return BaseClass::queryAggregation( rType );
@@ -287,9 +287,9 @@ namespace cppu
{ BaseClass::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ BaseClass::release(); }
- virtual com::sun::star::uno::Sequence< com::sun::star::uno::Type > SAL_CALL getTypes() throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException) SAL_OVERRIDE
{ return ImplInhHelper_getTypes( cd::get(), BaseClass::getTypes() ); }
- virtual com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (com::sun::star::uno::RuntimeException) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
}
@@ -67,7 +67,7 @@ namespace cppu
/// @endcond
- /** Implementation helper implementing interface com::sun::star::lang::XTypeProvider
+ /** Implementation helper implementing interface css::lang::XTypeProvider
and method XInterface::queryInterface(), but no reference counting.